<?php

declare(strict_types=1);

namespace Dedi\SyliusMigrationPlugin\Service\MigrationAction;

use Dedi\SyliusMigrationPlugin\Dto\MigrationOption;
use Dedi\SyliusMigrationPlugin\Service\Logger\MigrationLoggerInterface;
use Doctrine\DBAL\Connection;
use Psr\Log\LogLevel;

/**
 * Exemple de config :
 *
 *   truncate_table_before_migration:
 *     - [requete_sql]
 *     - ...
 */
class ExecuteQueryBeforeMigration extends AbstractMigrationAction implements PreMigrationActionInterface
{
    private readonly Connection $connection;

    private readonly MigrationLoggerInterface $migrationLogger;

    public function __construct(Connection $connection, MigrationLoggerInterface $migrationLogger)
    {
        $this->connection = $connection;
        $this->migrationLogger = $migrationLogger;
    }

    public function getType(): string
    {
        return 'execute_query_before_migration';
    }

    public function execute(MigrationOption $migrationOption): void
    {
        foreach ($this->options as $query) {
            $this->migrationLogger->log(LogLevel::INFO, $query);

            if (!$migrationOption->isDryRun()) {
                $this->connection->executeQuery($query);
            }
        }
    }
}
