<?php

declare(strict_types=1);

namespace Dedi\SyliusMigrationPlugin\Service\Sql;

use Dedi\SyliusMigrationPlugin\Service\ConnectionCheckerInterface;
use Doctrine\DBAL\Connection;
use Exception;
use Psr\Log\LoggerInterface;

class ConnectionChecker implements ConnectionCheckerInterface
{
    private readonly Connection $sourceConnection;

    private readonly Connection $targetConnection;

    private readonly LoggerInterface $logger;

    public function __construct(Connection $sourceConnection, Connection $targetConnection, LoggerInterface $logger)
    {
        $this->sourceConnection = $sourceConnection;
        $this->targetConnection = $targetConnection;
        $this->logger = $logger;
    }

    public function execute(): bool
    {
        $success = true;

        try {
            $this->sourceConnection->connect();
        } catch (Exception $e) {
            $success = false;
            $this->logger->error(sprintf('Could not connect to source database : %s', $e->getMessage()));
        }

        try {
            $this->targetConnection->connect();
        } catch (Exception $e) {
            $success = false;
            $this->logger->error(sprintf('Could not connect to target database : %s', $e->getMessage()));
        }

        return $success;
    }
}
